==> sm2-0.1.1.tar.gz: sm2-0.1.1/sm2/datasets/sunspots/data.py <==
"""Yearly sunspots data 1700-2008"""

__docformat__ = 'restructuredtext'

COPYRIGHT = """This data is public domain."""
TITLE = __doc__
SOURCE = """
http://www.ngdc.noaa.gov/stp/solar/solarda3.html

The original dataset contains monthly data on sunspot activity in the file
./src/sunspots_yearly.dat.  There is also sunspots_monthly.dat.
"""

DESCRSHORT = """Yearly (1700-2008) data on sunspots from the National
Geophysical Data Center."""

DESCRLONG = DESCRSHORT

NOTE = """::

    Number of Observations - 309 (Annual 1700 - 2008)
    Number of Variables - 1
    Variable name definitions::

        SUNACTIVITY - Number of sunspots for each year

    The data file contains a 'YEAR' variable that is not returned by load.
"""
import os

import numpy as np
import pandas as pd

from sm2.datasets.utils import Dataset


def load():
    """
    Load the yearly sunspot data and returns a data class.

    Returns
    --------
    Dataset instance:
        See DATASET_PROPOSAL.txt for more information.

    Notes
    -----
    This dataset only contains data for one variable, so the attributes
    data, raw_data, and endog are all the same variable.  There is no exog
    attribute defined.
    """
    data = _get_data()
    endog_name = 'SUNACTIVITY'
    endog = np.array(data[endog_name], dtype=float)
    dataset = Dataset(data=data, names=[endog_name], endog=endog,
                      endog_name=endog_name)
    return dataset


def load_pandas():
    data = pd.DataFrame(_get_data())
    # TODO: time series
    endog = pd.Series(data['SUNACTIVITY'], index=data['YEAR'].astype(int))
    dataset = Dataset(data=data, names=list(data.columns),
                      endog=endog, endog_name='volume')
    return dataset


def _get_data():
    cur_dir = os.path.dirname(os.path.abspath(__file__))
    path = os.path.join(cur_dir, 'sunspots.csv')
    data = pd.read_csv(path)
    return data.astype('f8').to_records(index=False)

==> sm2-0.1.3.tar.gz: sm2-0.1.3/sm2/datasets/sunspots/data.py <==
"""Yearly sunspots data 1700-2008"""
from sm2.datasets import utils as du

__docformat__ = 'restructuredtext'

COPYRIGHT = """This data is public domain."""
TITLE = __doc__
SOURCE = """
http://www.ngdc.noaa.gov/stp/solar/solarda3.html

The original dataset contains monthly data on sunspot activity in the file
./src/sunspots_yearly.dat.  There is also sunspots_monthly.dat.
"""

DESCRSHORT = """Yearly (1700-2008) data on sunspots from the National
Geophysical Data Center."""

DESCRLONG = DESCRSHORT

NOTE = """

    Number of Observations - 309 (Annual 1700 - 2008)
    Number of Variables - 1
    Variable name definitions::

        SUNACTIVITY - Number of sunspots for each year

    The data file contains a 'YEAR' variable that is not returned by load.
"""


def load_pandas():
    data = _get_data()
    # TODO: time series
    endog = data.set_index(data.YEAR).SUNACTIVITY
    dataset = du.Dataset(data=data, names=list(data.columns),
                         endog=endog, endog_name='volume')
    return dataset


def load(as_pandas=None):
    """
    Load the yearly sunspot data and returns a data class.

    Parameters
    ----------
    as_pandas : bool
        Flag indicating whether to return pandas DataFrames and Series
        or numpy recarrays and arrays.  If True, returns pandas.

    Returns
    --------
    Dataset instance:
        See DATASET_PROPOSAL.txt for more information.

    Notes
    -----
    This dataset only contains data for one variable, so the attributes
    data, raw_data, and endog are all the same variable.  There is no exog
    attribute defined.
    """
    return du.as_numpy_dataset(load_pandas(), as_pandas=as_pandas)


def _get_data():
    return du.load_csv(__file__, 'sunspots.csv').astype(float)
